# type: ignore[attr-defined]
"""Awesome `notion_renderer` is a Python cli/package created with https://github.com/TezRomacH/python-package-template"""

import sys

if sys.version_info >= (3, 8):
    from importlib import metadata as importlib_metadata
else:
    import importlib_metadata


def get_version() -> str:
    try:
        return importlib_metadata.version(__name__)
    except importlib_metadata.PackageNotFoundError:  # pragma: no cover
        return "unknown"


version: str = get_version()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['notion_renderer']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2',
 'cached-property>=1.5.2,<2.0.0',
 'commonmark>=0.9.1,<0.10.0',
 'dictdiffer>=0.9.0,<0.10.0',
 'python-slugify>=5.0.2,<6.0.0',
 'requests>=2.26.0,<3.0.0',
 'rich>=10.6.0,<11.0.0',
 'typer[all]>=0.3.2,<0.4.0',
 'tzlocal>=2.1,<3.0']

entry_points = \
{'console_scripts': ['notion_renderer = notion_renderer.__main__:app']}

setup_kwargs = {
    'name': 'notion-renderer',
    'version': '0.2.2',
    'description': 'Awesome `notion_renderer` is a Python cli/package created with https://github.com/TezRomacH/python-package-template',
    'long_description': '# notion_renderer\n',
    'author': 'notion_renderer',
    'author_email': 'ruucm.a@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/notion_renderer/notion_renderer',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



import json

import notion.client


class JsonPage:
    def toJSON(self):
        return json.dumps(self, default=lambda o: o.__dict__, sort_keys=True, indent=4)


def objectify_notion_collection(token_v2, collectionUrl, properties):
    """Convert a Notion collection to a Python object."""

    client = notion.client.NotionClient(token_v2=token_v2)
    cv = client.get_collection_view(collectionUrl)
    properties = properties.split(",")

    # collectionTitle = cv.collection.name
    collection_default = cv.default_query().execute()

    results = []

    for idx, page in enumerate(collection_default):
        jsonPage = JsonPage()

        for idx, property in enumerate(properties):
            setattr(jsonPage, property, getattr(page, property))

        jsonStr = jsonPage.toJSON()
        results.append(jsonStr)

    return results


def objectify_notion_blocks(token_v2, pageId):
    """Convert a Notion Page to a Python object."""

    client = notion.client.NotionClient(token_v2)
    page = client.get_block("https://www.notion.so/" + pageId)

    results = []

    for idx, content in enumerate(page.children):
        jsonPage = JsonPage()
        print("content.type", content.type)
        setattr(jsonPage, "type", content.type)
        if (
            content.type == "text"
            or content.type == "header"
            or content.type == "sub_header"
        ):
            setattr(jsonPage, "title", content.title)
        elif content.type == "image":
            # TODO: Store image locally
            # imagePath = utils.handleNotionImageSource(idx, content.source)
            # setattr(jsonPage, 'imagePath', imagePath)
            setattr(jsonPage, "imagePath", content.source)

        jsonStr = jsonPage.toJSON()
        results.append(jsonStr)

    return results
